@@ -536,6 +536,13 @@ class ZopePageTemplatesTest(RenderTestCase):
             "<div tal:define=\"__dummy 'foo'\">${__dummy}</div>",
             )
 
+    def test_disable_comment_interpolation(self):
+        template = self.from_string(
+            '<!-- ${"Hello world"} -->',
+            enable_comment_interpolation=False
+        )
+        self.assertEqual(template(), '<!-- ${"Hello world"} -->')
+
     def test_compiler_internals_are_disallowed(self):
         from chameleon.compiler import COMPILER_INTERNALS_OR_DISALLOWED
         from chameleon.exc import TranslationError
@@ -649,6 +656,14 @@ class ZopePageTemplatesTest(RenderTestCase):
         else:
             self.fail("Expected error.")
 
+    if tuple(sys.version_info) >= (3, 6, 0):
+        def test_f_strings(self):
+            from math import pi
+            from math import sin
+            template = self.from_string('${f"sin({a}) is {sin(a):.3}"}')
+            rendered = template(sin=sin, a=pi)
+            self.assertEqual('sin(3.141592653589793) is 1.2', rendered)
+
 
 class ZopeTemplatesTestSuite(RenderTestCase):
     def setUp(self):
